//import { marker } from "leaflet";
// map heler for leaflet
var maphelper;
(function (maphelper) {
    var MapType = /** @class */ (function () {
        function MapType(shortName, name, url, minZoom, maxZoom) {
            this.shortName = shortName;
            this.name = name;
            this.url = url;
            this.minZoom = minZoom;
            this.maxZoom = maxZoom;
        }
        return MapType;
    }());
    maphelper.MapType = MapType;
    var MyMarkerPoint = /** @class */ (function () {
        function MyMarkerPoint(latitude, longitude, explanation, url) {
            this.latitude = latitude;
            this.longitude = longitude;
            this.explanation = explanation;
            this.url = url;
        }
        return MyMarkerPoint;
    }());
    maphelper.MyMarkerPoint = MyMarkerPoint;
    maphelper.maps = [
        new MapType("r", "地理院地図", "https://cyberjapandata.gsi.go.jp/xyz/std/{z}/{x}/{y}.png", 2, 18),
        new MapType("a", "空中写真", "https://cyberjapandata.gsi.go.jp/xyz/seamlessphoto/{z}/{x}/{y}.jpg", 2, 18),
        new MapType("b", "2007年～", "https://cyberjapandata.gsi.go.jp/xyz/ort/{z}/{x}/{y}.jpg", 14, 18),
        new MapType("c", "2004年～", "https://cyberjapandata.gsi.go.jp/xyz/airphoto/{z}/{x}/{y}.png", 15, 18),
        new MapType("d", "1988～1990年", "https://cyberjapandata.gsi.go.jp/xyz/gazo4/{z}/{x}/{y}.jpg", 10, 17),
        new MapType("e", "1984～1986年", "https://cyberjapandata.gsi.go.jp/xyz/gazo3/{z}/{x}/{y}.jpg", 10, 17),
        new MapType("f", "1979～1983年", "https://cyberjapandata.gsi.go.jp/xyz/gazo2/{z}/{x}/{y}.jpg", 10, 17),
        new MapType("g", "1974～1978年", "https://cyberjapandata.gsi.go.jp/xyz/gazo1/{z}/{x}/{y}.jpg", 10, 17),
        new MapType("i", "1961～1969年", "https://cyberjapandata.gsi.go.jp/xyz/ort_old10/{z}/{x}/{y}.png", 10, 17),
        new MapType("j", "1945～1950年", "https://cyberjapandata.gsi.go.jp/xyz/ort_USA10/{z}/{x}/{y}.png", 10, 17),
        new MapType("k", "1936年頃", "https://cyberjapandata.gsi.go.jp/xyz/ort_riku10/{z}/{x}/{y}.png", 13, 18),
        new MapType("l", "色別標高図", "https://cyberjapandata.gsi.go.jp/xyz/relief/{z}/{x}/{y}.png", 5, 15),
        new MapType("m", "陰影起伏図", "https://cyberjapandata.gsi.go.jp/xyz/hillshademap/{z}/{x}/{y}.png", 2, 16),
    ];
})(maphelper || (maphelper = {}));
function getAllMaps() {
    return maphelper.maps;
}
function getTargetMaps(shortName) {
    if (shortName == "h")
        return maphelper.maps[1]; // force to return "a"
    for (var i = 0; i < maphelper.maps.length; i++) {
        if (maphelper.maps[i].shortName == shortName)
            return maphelper.maps[i];
    }
    return maphelper.maps[0];
}
function createGM(targetElementId, shortMapName, xSize, ySize, centerLatitude, centerLongitude, zoomLevel, markers, isLine, afterProc) {
    if (afterProc === void 0) { afterProc = null; }
    setTimeout(function () {
        var map = getTargetMaps(shortMapName);
        if (!xSize)
            xSize = "100%";
        $("#" + targetElementId).css("width", xSize);
        if (!ySize)
            ySize = "20em";
        $("#" + targetElementId).css("height", ySize);
        if (!zoomLevel)
            zoomLevel = 13;
        if (map.maxZoom < zoomLevel)
            zoomLevel = map.maxZoom;
        if (map.minZoom > zoomLevel)
            zoomLevel = map.minZoom;
        var mymap = L.map(targetElementId).setView([centerLatitude, centerLongitude], zoomLevel);
        //let options: any = new Object();
        //options.maxZoom = map.maxZoom;
        //options.minZoom = map.minZoom;
        var baseLayers = new Object();
        var shortNameToLayer = new Object();
        var maps = getAllMaps();
        for (var i = 0; i < maps.length; i++) {
            var options = new Object();
            options.maxZoom = maps[i].maxZoom;
            options.minZoom = maps[i].minZoom;
            //options.id = targetElementId + "_sel" + i.toString();
            baseLayers[maps[i].name] = L.tileLayer(maps[i].url, options);
            shortNameToLayer[maps[i].shortName] = baseLayers[maps[i].name];
            if (maps[i].shortName == shortMapName) {
                baseLayers[maps[i].name].addTo(mymap);
            }
        }
        L.control.layers(baseLayers).addTo(mymap);
        //mymap.attributionControl.addAttribution('This is attr <a href="http://www.piedey.co.jp/">LINK</a>');
        if (!markers || markers.length == 0) {
            markers = [
                new maphelper.MyMarkerPoint(centerLatitude, centerLongitude, null, null)
            ];
        }
        if (isLine && markers.length >= 2) {
            // line mode 
            var latlngs = [];
            for (var i = 0; i < markers.length; i++) {
                latlngs.push(new L.LatLng(markers[i].latitude, markers[i].longitude));
            }
            L.polyline(latlngs, { color: 'red' }).addTo(mymap);
        }
        // marker/line mode common
        var lmarkers = [];
        var _loop_1 = function () {
            var options = new Object();
            if (markers[i].explanation)
                options.title = markers[i].explanation;
            var marker = L.marker([markers[i].latitude, markers[i].longitude], options).addTo(mymap);
            lmarkers.push(marker);
            var url = markers[i].url;
            var m = marker;
            var tooltip = String.fromCharCode('A'.charCodeAt(0) + i);
            if (markers[i].explanation && markers[i].explanation != "*") {
                tooltip += ": " + markers[i].explanation;
            }
            m.bindTooltip(tooltip, { permanent: true, interactive: !!url }); //.openTooltip();
            if (url)
                marker.on('click', function () {
                    location.href = url;
                });
        };
        for (var i = 0; i < markers.length; i++) {
            _loop_1();
        }
        if (markers.length >= 2) {
            mymap.fitBounds(L.featureGroup(lmarkers).getBounds());
        }
        if (afterProc) {
            // for AdminWrite mode
            afterProc(mymap, lmarkers[0], baseLayers, shortNameToLayer);
        }
        else {
            // for normal mode
            // create additional UI
            var p = document.createElement('p');
            $(p).append("[");
            var a1 = document.createElement('a');
            $(a1).attr("href", "#");
            $(a1).click(function () {
                mymap.setView([centerLatitude, centerLongitude], zoomLevel);
            });
            $(a1).text("RESET");
            $(p).append(a1);
            $(p).append("]");
            $(p).append("[");
            var a2 = document.createElement('a');
            $(a2).attr("href", "#");
            $(a2).click(function () {
                var group = L.featureGroup(lmarkers);
                mymap.fitBounds(group.getBounds());
            });
            $(a2).text("VIEW ALL");
            $(p).append(a2);
            $(p).append("]");
            var _loop_2 = function () {
                $(p).append("[");
                var a3 = document.createElement('a');
                $(a3).attr("href", "#");
                var m = lmarkers[i];
                $(a3).click(function () {
                    var group = L.featureGroup([m]);
                    mymap.fitBounds(group.getBounds());
                });
                var tooltip = String.fromCharCode('A'.charCodeAt(0) + i);
                if (markers[i].explanation && markers[i].explanation != "*") {
                    tooltip += ": " + markers[i].explanation;
                }
                $(a3).text(tooltip);
                $(p).append(a3);
                $(p).append("]");
            };
            for (var i = 0; i < markers.length; i++) {
                _loop_2();
            }
            $("#" + targetElementId).after(p);
        }
    }, 0);
}
function initForAdminWriteOnly() {
    $("#MiscPanelActivator").click(function () {
        $("#miscPanel").css("display", "block");
        $("#MiscPanelActivator").css("display", "none");
    });
    $("#GMPickerActivator").click(function () {
        $("#map_frame").css("display", "block");
        $("#GMPickerActivator").css("display", "none");
        var lat = 35.68093426903065;
        var lon = 139.76703643798828;
        var zoom = 13;
        var shortName = "r";
        if (localStorage.getItem("lat"))
            lat = Number(localStorage.getItem("lat"));
        if (localStorage.getItem("lon"))
            lon = Number(localStorage.getItem("lon"));
        if (localStorage.getItem("zoom"))
            zoom = Number(localStorage.getItem("zoom"));
        if (localStorage.getItem("shortName"))
            shortName = localStorage.getItem("shortName");
        createGM("map_canvas", shortName, "500px", "300px", lat, lon, zoom, null, false, function (mymap, marker, baseLayers, shortNameToLayer) {
            var updateMessages = function () {
                marker.setLatLng(mymap.getCenter());
                var myshortName = null;
                for (var key in baseLayers) {
                    if (mymap.hasLayer(baseLayers[key])) {
                        for (var shortNameEx in shortNameToLayer) {
                            if (shortNameToLayer[shortNameEx] == baseLayers[key]) {
                                myshortName = shortNameEx;
                                break;
                            }
                        }
                        if (myshortName)
                            break;
                    }
                }
                var center = mymap.getCenter();
                $("#message1").text("$$gmp ,," + center.lat + "," + center.lng
                    + "," + mymap.getZoom() + "," + myshortName);
                $("#message2").text("," + center.lat + "," + center.lng + ",*,");
                lat = mymap.getCenter().lat;
                lon = mymap.getCenter().lng;
                zoom = mymap.getZoom();
                shortName = myshortName;
            };
            $(window).bind("beforeunload", function () {
                updateMessages();
                localStorage.setItem("lat", lat.toString());
                localStorage.setItem("lon", lon.toString());
                localStorage.setItem("zoom", zoom.toString());
                localStorage.setItem("shortName", shortName);
            });
            mymap.on('moveend', function (e) {
                updateMessages();
            });
            $("#insertGMP").click(function () {
                updateMessages();
                $("#TextBoxBody").val($("#TextBoxBody").val() + $("#message1").text());
            });
            $("#addPoint").click(function () {
                updateMessages();
                $("#TextBoxBody").val($("#TextBoxBody").val() + $("#message2").text());
            });
            $("#comeHere").click(function () {
                if (navigator.geolocation) {
                    navigator.geolocation.getCurrentPosition(function (position) {
                        mymap.setView([position.coords.latitude, position.coords.longitude]);
                    }, function (error) {
                        var errorMessage = {
                            0: "原因不明のエラーが発生しました…。",
                            1: "位置情報の取得が許可されませんでした…。",
                            2: "電波状況などで位置情報が取得できませんでした…。",
                            3: "位置情報の取得に時間がかかり過ぎてタイムアウトしました…。",
                        };
                        // エラーコードに合わせたエラー内容をアラート表示
                        alert(errorMessage[error.code]);
                    });
                }
                else {
                    // Geolocation APIに対応していない
                    alert("あなたの端末では、現在位置を取得できません。");
                }
            });
        });
    });
}
var allInitializers = [];
function kickAllInitializers() {
    for (var i = 0; i < allInitializers.length; i++) {
        allInitializers[i](null);
    }
    allInitializers = [];
}
//# sourceMappingURL=maphelper.js.map